<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-dev',
'0_langue' => 'Bosanski [bs]',
'0_liste' => 'spip-dev@rezo.net',
'0_mainteneur' => 'nerina corbadzic <muzevira@googlemail.com>',

// A
'access_interface_graphique' => 'Nazad na kompletno graficki interfejs',
'access_mode_texte' => 'Prikazi pojednostavljeni tekstualni interfejs',
'admin_debug' => 'debug',
'admin_modifier_article' => 'Izmijeni ovaj clanak',
'admin_modifier_auteur' => 'Izmijeni ovog autora',
'admin_modifier_breve' => 'Izmijeni ovo obavjestenje',
'admin_modifier_mot' => 'Izmijeni ovu kljucnu rijec',
'admin_modifier_rubrique' => 'Izmijeni ovu rubriku',
'admin_recalculer' => 'Osvjezi ovu stranicu',
'afficher_trad' => 'afficher les traductions', # NEW
'alerte_maj_impossible' => '<b>Paznja!</b> Osvjezavanje SQL baze podataka na verziju @version@ nije uspjelo. Mozda se radi o dozvoli na bazi podataka. Molimo, kontaktirajte vas ISP.', # MODIF
'alerte_modif_info_concourante' => 'ATTENTION : Cette information a &eacute;t&eacute; modifi&eacute;e par ailleurs. La valeur actuelle est&nbsp;:', # NEW
'analyse_xml' => 'Obrada XML',
'annuler' => 'Annuler', # NEW
'antispam_champ_vide' => 'Veuillez laisser ce champ vide&nbsp;:', # NEW
'articles_recents' => '&#1055;&#1086;&#1089;&#1083;&#1077;&#1076;&#1085;&#1112;&#1080; &#1063;&#1083;&#1072;&#1085;&#1094;&#1080;',
'avis_archive_incorrect' => 'arhiv dokument nije vazeci SPIP dokument',
'avis_archive_invalide' => 'arhiv dokument nije vazeci',
'avis_attention' => 'OPREZ!',
'avis_champ_incorrect_type_objet' => 'Pogresno ime polja @name@ za objekat tipa @type@',
'avis_colonne_inexistante' => 'Colona @col@ ne postoji',
'avis_echec_syndication_01' => 'Sindikacija nije uspjela: odabrani backend nije citljiv ili ne nudi nijedan clanak.',
'avis_echec_syndication_02' => 'Sindikacija nije uspjela: nije moguce dostici backend ove stranice',
'avis_erreur' => 'Greska: vidi ispod',
'avis_erreur_connexion' => 'Greska u konekciji',
'avis_erreur_cookie' => 'Problem sa cookiem',
'avis_erreur_fonction_contexte' => 'Greska u programiranju.Ova funkcija se ne treba pozivati u ovom kontekstu.', # MODIF
'avis_erreur_mysql' => 'SQL greska', # MODIF
'avis_erreur_sauvegarde' => 'Backup greska (@type@ @id_objet@) !',
'avis_erreur_visiteur' => 'Probl&egrave;me d\'acc&egrave;s &agrave; l\'espace priv&eacute;', # NEW

// B
'barre_a_accent_grave' => 'Unesi veliko A sa grave akcentom',
'barre_aide' => 'Obogatite izgled vaseg teksta, koristeci se tipografskim precicama',
'barre_e_accent_aigu' => 'Unesi veliko E sa akutnim akcentom',
'barre_eo' => 'Unesi eo ligaturu',
'barre_eo_maj' => 'Unesi EO ligaturu velikim slovima',
'barre_euro' => 'Unesi simbol za euro',
'barre_gras' => 'Pretvori u {{masna slova}}',
'barre_guillemets' => 'Stavi pod "duple navodne znake"',
'barre_guillemets_simples' => 'Stavi pod "navodne znake"',
'barre_intertitre' => 'Pretvori u {{{podnaslov}}}',
'barre_italic' => 'Pretvori u {italik}',
'barre_lien' => 'pretvori u [hiperlink->http://...]',
'barre_lien_input' => 'Unesite odrediste vaseg hiperlinka (mozete unijeti internet URL u formi http://www.mysite.com ili navesti broj clanka na ovoj stranici.',
'barre_note' => 'Pretvori u [[fusnotu]]',
'barre_paragraphe' => 'Cr&#233;er un paragraphe', # NEW
'barre_quote' => '<quote>citiraj neku poruku</quote>',
'bouton_ajouter_document' => 'DODAJ DOKUMENT', # MODIF
'bouton_ajouter_image' => 'DODAJ FOTOGRAFIJU', # MODIF
'bouton_ajouter_image_document' => 'Ajouter une image ou&nbsp;un&nbsp;document', # NEW
'bouton_changer' => 'Izmijeni',
'bouton_chercher' => 'Pretraga',
'bouton_choisir' => 'Izaberi',
'bouton_download' => 'T&eacute;l&eacute;charger', # NEW
'bouton_enregistrer' => 'Snimi',
'bouton_radio_desactiver_messagerie_interne' => 'Dezaktiviraj interni servis poruka',
'bouton_radio_envoi_annonces' => 'Posalji editorijalne najave',
'bouton_radio_non_envoi_annonces' => 'Ne salji najave',
'bouton_radio_non_envoi_liste_nouveautes' => 'Ne salji listu novosti',
'bouton_recharger_page' => 'Osvjezi ovu stranicu',
'bouton_telecharger' => 'Download',
'bouton_valider' => 'Ovjeri',

// C
'cal_apresmidi' => 'posljepodne',
'cal_jour_entier' => 'cijeli dan',
'cal_matin' => 'prijepodne',
'cal_par_jour' => 'dnevni kalendar',
'cal_par_mois' => 'mjesecni kalendar',
'cal_par_semaine' => 'sedmicni kalendar',
'choix_couleur_interface' => 'couleur ', # NEW
'choix_interface' => 'choix  de l\'interface', # NEW
'colonne' => 'Colonne', # NEW
'confirm_changer_statut' => 'Trazili ste izmjenu statusa ovog clanka. Zelite li nastaviti?',
'correcte' => 'tacno',

// D
'date_aujourdhui' => 'danas',
'date_avant_jc' => 'pne.',
'date_dans' => 'za @delai@',
'date_de_mois_1' => '@j@ @nommois@',
'date_de_mois_10' => '@j@ @nommois@',
'date_de_mois_11' => '@j@ @nommois@',
'date_de_mois_12' => '@j@ @nommois@',
'date_de_mois_2' => '@j@ @nommois@',
'date_de_mois_3' => '@j@ @nommois@',
'date_de_mois_4' => '@j@ @nommois@',
'date_de_mois_5' => '@j@ @nommois@',
'date_de_mois_6' => '@j@ @nommois@',
'date_de_mois_7' => '@j@ @nommois@',
'date_de_mois_8' => '@j@ @nommois@',
'date_de_mois_9' => '@j@ @nommois@',
'date_demain' => 'sutra',
'date_fmt_heures_minutes' => '@h@h@m@min',
'date_fmt_jour_heure' => '@jour@ u @heure@',
'date_fmt_jour_mois' => '@jour@ @nommois@',
'date_fmt_jour_mois_annee' => '@jour@ @nommois@ @annee@',
'date_fmt_mois_annee' => '@nommois@ @annee@',
'date_fmt_nomjour_date' => '@nomjour@ @date@',
'date_heures' => 'sati',
'date_hier' => 'jucer',
'date_il_y_a' => 'prije @delai@',
'date_jnum1' => '1',
'date_jnum10' => '10',
'date_jnum11' => '11',
'date_jnum12' => '12',
'date_jnum13' => '13',
'date_jnum14' => '14',
'date_jnum15' => '15',
'date_jnum16' => '16',
'date_jnum17' => '17',
'date_jnum18' => '18',
'date_jnum19' => '19',
'date_jnum2' => '2',
'date_jnum20' => '20',
'date_jnum21' => '21',
'date_jnum22' => '22',
'date_jnum23' => '23',
'date_jnum24' => '24',
'date_jnum25' => '25',
'date_jnum26' => '26',
'date_jnum27' => '27',
'date_jnum28' => '28',
'date_jnum29' => '29',
'date_jnum3' => '3',
'date_jnum30' => '30',
'date_jnum31' => '31',
'date_jnum4' => '4',
'date_jnum5' => '5',
'date_jnum6' => '6',
'date_jnum7' => '7',
'date_jnum8' => '8',
'date_jnum9' => '9',
'date_jour_1' => 'nedjelja',
'date_jour_1_abbr' => 'dim.', # NEW
'date_jour_1_initiale' => 'd.', # NEW
'date_jour_2' => 'ponedjeljak',
'date_jour_2_abbr' => 'lun.', # NEW
'date_jour_2_initiale' => 'l.', # NEW
'date_jour_3' => 'utorak',
'date_jour_3_abbr' => 'mar.', # NEW
'date_jour_3_initiale' => 'm.', # NEW
'date_jour_4' => 'srijeda',
'date_jour_4_abbr' => 'mer.', # NEW
'date_jour_4_initiale' => 'm.', # NEW
'date_jour_5' => 'cetvrtak',
'date_jour_5_abbr' => 'jeu.', # NEW
'date_jour_5_initiale' => 'j.', # NEW
'date_jour_6' => 'petak',
'date_jour_6_abbr' => 'ven.', # NEW
'date_jour_6_initiale' => 'v.', # NEW
'date_jour_7' => 'subota',
'date_jour_7_abbr' => 'sam.', # NEW
'date_jour_7_initiale' => 's.', # NEW
'date_jours' => 'dani',
'date_minutes' => 'minute',
'date_mois' => 'mjeseci',
'date_mois_1' => 'januar',
'date_mois_10' => 'oktobar',
'date_mois_11' => 'novembar',
'date_mois_12' => 'decembar',
'date_mois_2' => 'februar',
'date_mois_3' => 'mart',
'date_mois_4' => 'april',
'date_mois_5' => 'maj',
'date_mois_6' => 'juni',
'date_mois_7' => 'juli',
'date_mois_8' => 'august',
'date_mois_9' => 'septembar',
'date_saison_1' => 'zima',
'date_saison_2' => 'proljece',
'date_saison_3' => 'ljeto',
'date_saison_4' => 'jesen',
'date_secondes' => 'secondes', # NEW
'date_semaines' => 'sedmice',
'date_un_mois' => 'mois', # NEW
'date_une_heure' => 'heure', # NEW
'date_une_minute' => 'minute', # NEW
'date_une_seconde' => 'seconde', # NEW
'date_une_semaine' => 'semaine', # NEW
'dirs_commencer' => ' da bi ste poceli sa stvarnom instalacijom',
'dirs_preliminaire' => 'Uvod: <b>Podesavanje dozvola za pristup</b>',
'dirs_probleme_droits' => '<b>Problem sa dozvolama za pristup</b>',
'dirs_repertoires_absents' => '<b>Sljedeci direktoriji nisu nadjeni: <ul>@bad_dirs@.</ul> </b>
  <p>Problem je vjerovatno u pisanju velikih i malih slova.
  Provjerite da li velika i mala slova ovih direktorija odgovaraju onom sto je prikazano nize; ako to nije slucaj, promijenite imena direktorija pomocu vaseg FTP klijenta, da biste ispravili gresku.
  </p><p>Kada to uradite, mozete </p>', # MODIF
'dirs_repertoires_suivants' => '<b>Sljedeci direktoriji ne dozvoljavaju pisanje: <ul>@bad_dirs@.</ul> </b>
  <p>Da bi ste to promijenili, koristite svog FTP klijenta i postavite dozvole pristupa za svaki od direktorija. Procedura je detaljno opisana u uputama za instalaciju.
  </p><p>Kada izvrsite ovu operaciju, mozete </p>', # MODIF
'double_occurrence' => 'Double occurrence', # MODIF

// E
'en_cours' => 'en cours', # NEW
'entree_dimensions' => 'Dimenzije:',
'entree_titre_document' => 'Naziv dokumenta:',
'entree_titre_image' => 'Naziv fotografije:',
'envoi_via_le_site' => 'Poslano putem stranice',
'erreur' => 'Erreur', # NEW
'erreur_balise_non_fermee' => 'derni&egrave;re balise non referm&eacute;e :', # NEW
'erreur_texte' => 'erreur(s)', # NEW
'etape' => '&Eacute;tape', # NEW

// F
'fichier_introuvable' => 'Dokument @fichier@ nije pronadjen',
'form_auteur_confirmation' => 'Confirmez votre adresse email', # NEW
'form_auteur_email_modifie' => 'Votre adresse email a &eacute;t&eacute; modifi&eacute;e.', # NEW
'form_auteur_envoi_mail_confirmation' => 'Un courrier &eacute;lectronique de confirmation vient d\'&ecirc;tre envoy&eacute; &agrave; @email@. Vous devrez visiter l\'adresse Web mentionn&eacute;e dans ce courrier pour valider votre adresse mail.', # NEW
'form_auteur_mail_confirmation' => 'Bonjour,

Vous avez demand&eacute; &agrave; changer votre adresse email.
Pour confirmer votre nouvelle adresse, il suffit de vous connecter &agrave;
l\'adresse ci-dessous (dans le cas contraire, votre demande
sera ignor&eacute;e) :

    @url@
', # NEW
'form_deja_inscrit' => 'Vec ste registrovani.',
'form_email_non_valide' => 'Vasa e-mail adresa nije vazeca.',
'form_forum_access_refuse' => 'Nemate vise pristup ovoj stranici.',
'form_forum_bonjour' => 'Dobar dan @nom@,',
'form_forum_email_deja_enregistre' => 'Ova e-mail adresa je vec registrovana. Mozete koistiti vasu uobicajenu lozinku',
'form_forum_identifiant_mail' => 'Vas novi identifikator vam je upravo poslan na vasu e-mail adresu.',
'form_forum_identifiants' => 'Licni identifikatori',
'form_forum_indiquer_nom_email' => 'Ovdje upisite vase ime i e-mail adresu. Ubrzo ce na tu adresu stici vas licni identifikator.',
'form_forum_login' => 'login:',
'form_forum_message_auto' => '(ovo je automatska poruka)',
'form_forum_pass' => 'lozinka:',
'form_forum_probleme_mail' => 'Problem sa e-mail adresom. Identifikator nije poslan.',
'form_forum_voici1' => 'Ovo su identifikatori za vase ucesce u aktivnosti stranice "@nom_site_spip@" (@adresse_site@/) :',
'form_forum_voici2' => 'Ovo su vasi identifikatori za postavljanje clanaka na stranici "@nom_site_spip@" (@adresse_site@/ecrire/) :',
'form_indiquer_email' => 'Naznacite vasu e-mail adresu.',
'form_indiquer_nom' => 'Naznacite vase ime.',
'form_indiquer_nom_site' => 'Naznacite ime vase stranice.',
'form_pet_adresse_site' => 'Adresa vase stranice',
'form_pet_aucune_signature' => 'Nijedan potpis ne odgovara ovom kodu...',
'form_pet_confirmation' => 'Potvrdite vas potpis:',
'form_pet_deja_enregistre' => 'Ova stranica je vec registrovana',
'form_pet_deja_signe' => 'Vec ste potpisali ovaj tekst.',
'form_pet_envoi_mail_confirmation' => 'Upravo vam je poslan e-mail sa potvrdom. Trebate posjetiti web stranicu naznacenu u tom e-mailu, da bi ste ovjerili vas potpis.', # MODIF
'form_pet_mail_confirmation' => 'Dobar dan',
'form_pet_message_commentaire' => 'Da li zelite napisati poruku ili komentar?',
'form_pet_nom_site2' => 'Ime vase web stranice',
'form_pet_probleme_liens' => 'Veuillez reprendre votre message en supprimant les liens hypertexte.', # NEW
'form_pet_probleme_technique' => 'Tehnicki problem, potpisi su trenutno nedostupni.',
'form_pet_signature_pasprise' => 'Vas potpis nije primljen.',
'form_pet_signature_validee' => 'Vas potpis je vazeci. Hvala!',
'form_pet_site_deja_enregistre' => 'Ova stranica je vec registrovana',
'form_pet_url_invalide' => 'URL adresa koju ste naznacili nije vazeca.',
'form_pet_votre_email' => 'Vasa e-mail adresa',
'form_pet_votre_nom' => 'Vase ime ili pseudo',
'form_pet_votre_site' => 'Ako imate web stranicu, mozete je naznaciti ispod',
'form_prop_confirmer_envoi' => 'Potvrdi posiljku',
'form_prop_description' => 'Opis/komentar',
'form_prop_enregistre' => 'Vas prijedlog je registrovan i bice postavljen nakon ovjere od strane odgovornih osoba ove stranice.',
'form_prop_envoyer' => 'Posalji poruku',
'form_prop_indiquer_email' => 'Naznacite vazecu e-mail adresu',
'form_prop_indiquer_nom_site' => 'Naznacite ime strancie.',
'form_prop_indiquer_sujet' => 'Naznacite temu',
'form_prop_message_envoye' => 'Poruka poslana',
'form_prop_nom_site' => 'Naziv stranice',
'form_prop_non_enregistre' => 'Vas prijedlog nije registrovan.',
'form_prop_sujet' => 'Tema',
'form_prop_url_site' => 'URL adresa stranice',
'forum_acces_refuse' => 'Nemate vise pristup ovim forumima.',
'forum_attention_dix_caracteres' => '<b>Upozorenje!</b> Vasa poruka mora sadrzati najmanje deset karaktera.',
'forum_attention_trois_caracteres' => '<b>Upozorenje!</b> Vas naslov mora sadrzati najmanje tri karaktera.',
'forum_attention_trop_caracteres' => '<b>Attention&nbsp;!</b> votre message est trop long (@compte@ caract&egrave;res)&nbsp;: pour pouvoir &ecirc;tre enregistr&eacute;, il ne doit pas d&eacute;passer @max@ caract&egrave;res.', # NEW
'forum_avez_selectionne' => 'Izabrali ste:',
'forum_cliquer_retour' => 'Kliknite <a href=\'@retour_forum@\'>ici</a> da bi ste nastavili.',
'forum_forum' => 'forum',
'forum_info_modere' => 'Ovaj forum je vlasnistvo urednika: vas prijedlog ce biti postavljen tek nakon sto je ovjeren od strane administratora.',
'forum_lien_hyper' => '<b>Hipertekstualni link</b> (optionnel)',
'forum_message_definitif' => 'Definitivna poruka: posalji na stranicu',
'forum_message_trop_long' => 'Vasa poruka je preduga. Maksimalna velicina je 20000 karaktera.',
'forum_ne_repondez_pas' => 'Ne odgovarajte na ovu poruku osim u forumu na sljedecu adresu:',
'forum_non_inscrit' => 'Niste registrovani ili adresa i lozinka nisu ispravni.',
'forum_page_url' => '(Ako se vasa poruka odnosi na clanak objavljen na web-u, ili na stranicu koja pruza dodatne informacije, mozete na kraju naznaciti naziv i URL adresu stranice.)',
'forum_par_auteur' => 'od @auteur@',
'forum_poste_par' => 'Poruku postavio/la@parauteur@; poruka slijedi nakon vaseg clanka.', # MODIF
'forum_probleme_database' => 'Problem sa bazom podataka, Vasa poruka nije registrovana.',
'forum_qui_etes_vous' => '<b>Ko ste?</b> (optionnel)',
'forum_texte' => 'Tekst vase poruke:',
'forum_titre' => 'Tema:',
'forum_titre_erreur' => 'Greska...',
'forum_url' => 'URL:',
'forum_valider' => 'Ptvrdite ovaj izbor',
'forum_voir_avant' => 'Pogledaj poruku',
'forum_votre_email' => 'Vasa e-mail adresa:',
'forum_votre_nom' => 'Vase ime (ili pseudonim):',
'forum_vous_enregistrer' => 'Da bi ste ucestvovali u ovom forumu, morate se prijaviti. Naznacite ispod licni identifikator koji vam je dodjeljen. Ako niste vec registrovani, trebate',
'forum_vous_inscrire' => 'se upisati.',

// I
'ical_texte_rss_articles' => 'Backend dokument clanaka ove stranice se nalazi na adresi:',
'ical_texte_rss_articles2' => 'Svakako mozete dobiti backend dokumente za clanke svih rubrika na stanici:',
'ical_texte_rss_breves' => 'Postoji dokument koji sadrzi novosti stranice. Mozete dobiti samo novosti jedne rubrike, tako sto ce te izabrati broj sekcije.',
'icone_a_suivre' => '&Agrave; suivre',
'icone_admin_site' => 'Administracija stranice',
'icone_agenda' => 'Kalendar',
'icone_aide_ligne' => 'Pomoc',
'icone_articles' => 'Clanci',
'icone_auteurs' => 'Autori',
'icone_breves' => 'Obavjestenja',
'icone_brouteur' => 'Brza navigacija',
'icone_configuration_site' => 'Podesavanje',
'icone_configurer_site' => 'Podesavanje vase stranice',
'icone_creer_nouvel_auteur' => 'Kreiraj novog autora',
'icone_creer_rubrique' => 'Kreiraj rubriku',
'icone_creer_sous_rubrique' => 'Kreiraj podrubriku',
'icone_deconnecter' => 'odjava',
'icone_discussions' => 'Diskusije',
'icone_doc_rubrique' => 'Prilozeni dokumenti',
'icone_ecrire_article' => 'Napisi novi clanak',
'icone_edition_site' => 'Izmjena',
'icone_forum_administrateur' => 'Forum administratora',
'icone_forum_suivi' => 'Pracenje foruma',
'icone_gestion_langues' => 'Menadzer jezika',
'icone_informations_personnelles' => 'Licne informacije',
'icone_interface_complet' => 'cjelokupni interfejs',
'icone_interface_simple' => 'Pojednostavljeni interfejs',
'icone_maintenance_site' => 'Odrzavanje stranice',
'icone_messagerie_personnelle' => 'Licni servis poruka',
'icone_mots_cles' => 'Kljucne rijeci',
'icone_nouvelle_breve' => 'Napisi novo obavjestenje',
'icone_repartition_actuelle' => 'Prikazi trenutnu distribuciju',
'icone_repartition_debut' => 'Prikazi distribuciju od pocetka',
'icone_repartition_visites' => 'Distribucija posjeta',
'icone_rubriques' => 'Rubrike',
'icone_sauver_site' => 'Backup stranice',
'icone_site_entier' => 'Cjela stranica',
'icone_sites_references' => 'Preporucene stranice',
'icone_statistiques' => 'Statistike stranice',
'icone_statistiques_visites' => 'Statistike',
'icone_suivi_activite' => 'Prati aktivnost stranice',
'icone_suivi_actualite' => 'Razvoj stranice',
'icone_suivi_forums' => 'Prati/uredi foruma',
'icone_suivi_pettions' => 'Prati/uredi peticija',
'icone_suivi_revisions' => 'Izmjene clanaka',
'icone_supprimer_document' => 'Izbrisi ovaj dokument',
'icone_supprimer_image' => 'Izbrisi ovu fotografiju',
'icone_supprimer_message' => 'Izbrisi ovu poruku',
'icone_tous_articles' => 'Svi vasi clanci',
'icone_tous_auteur' => 'Svi autori',
'icone_valider_message' => 'Ovjeri ovu poruku',
'icone_visiter_site' => 'Posjeti',
'icone_voir_en_ligne' => 'Pogledaj online',
'image_tourner_180' => 'Okreni za 180°',
'image_tourner_droite' => 'Okreni 90° na desnu stranu',
'image_tourner_gauche' => 'Okreni 90° na lijevu stranu',
'img_indisponible' => 'fotografija je nedostupna',
'impossible' => 'impossible', # NEW
'info_a_suivre' => 'LAUNCH PAD&raquo;',
'info_a_valider' => '[za ovjeriti]',
'info_acces_interdit' => 'zabranjen pristup',
'info_acces_refuse' => 'pristup odbijen',
'info_action' => 'Akcija: @action@',
'info_administrer_rubriques' => 'Mozete administrirati ovu rubriku i njene podrubrike',
'info_adresse_non_indiquee' => 'Niste naznacili adresu koju treba testirati!',
'info_aide' => 'POMOC:',
'info_ajouter_mot' => 'Dodaj ovu rijec',
'info_annonce' => 'NAJAVA',
'info_annonces_generales' => 'Opste najave:',
'info_article_propose' => 'Clanak je predlozen',
'info_article_publie' => 'Clanak je objavljen',
'info_article_redaction' => 'Clanak u toku uredjivanja',
'info_article_refuse' => 'Clanak je odbijen',
'info_article_supprime' => 'Clanak je izbrisan',
'info_articles' => '&#1063;&#1083;&#1072;&#1085;&#1094;&#1080;',
'info_articles_a_valider' => 'Clanci za ovjeriti',
'info_articles_nb' => '@nb@ articles', # NEW
'info_articles_proposes' => 'Predlozeni clanci',
'info_articles_un' => '1 article', # NEW
'info_auteurs_nombre' => 'autor/i:',
'info_authentification_ftp' => 'Authentifikacija (FTP-om).',
'info_bloquer_lien' => 'blokiraj ovaj link',
'info_breves_02' => 'Obavjestenja',
'info_breves_2' => 'obavjestenja',
'info_breves_nb' => '@nb@ br&egrave;ves', # NEW
'info_breves_un' => '1 br&egrave;ve', # NEW
'info_breves_valider' => 'Obavjestenja za ovjeriti',
'info_connexion_refusee' => 'Prijava odbijena',
'info_contact_developpeur' => 'Kontaktirajte programera.',
'info_contenance' => 'Ova stranica sadrzi:',
'info_contribution' => 'Pridonos foruma',
'info_copyright' => '@spip@ je slobodni softver distribucije @lien_gpl@.',
'info_copyright_doc' => 'Za vise informacija pogledajte <a href="@spipnet@">http://www.spip.net/fr</a>.', # MODIF
'info_copyright_gpl' => 'pod GPL licencom',
'info_cours_edition' => 'Vasi clanci u toku uredjivanja',
'info_creer_repertoire' => 'Kreirajte dokument ili direktorij pod imenom:',
'info_creer_repertoire_2' => 'Unutar podirektorija<b>ecrire/data/</b>, zatim:',
'info_creer_vignette' => 'automatska kreacija vinjete',
'info_deplier' => 'Otvori',
'info_descriptif_nombre' => 'opis/i:',
'info_description' => 'Opis:',
'info_description_2' => 'Opis:',
'info_dimension' => 'Dimenzije:',
'info_document' => 'Dokument',
'info_document_indisponible' => 'Ce document n\'est pas disponible', # NEW
'info_documents' => 'Dokumenti',
'info_documents_nb' => '@nb@ documents', # NEW
'info_documents_un' => '1 document', # NEW
'info_echange_message' => 'SPIP dozvoljava razmjenu poruka izmedju ucesnika stranice i kreiranje privatnih foruma za diskusiju. Mozete ukljuciti ili iskljuciti ovu funkciju.',
'info_ecire_message_prive' => 'Napisi privatnu poruku',
'info_email_invalide' => 'Pogresna e-mail adresa.',
'info_en_cours_validation' => 'Vasi clanci u toku uredjivanja',
'info_en_ligne' => 'Trenutno online:',
'info_envoyer_message_prive' => 'Posalji privatnu poruku ovom autoru',
'info_erreur_requete' => 'Greska sa upitom:',
'info_erreur_squelette2' => 'Nijedan predlozak <b>@fichier@</b> nije dostupan...',
'info_erreur_systeme' => 'Sistemska greska (errno @errsys@)',
'info_erreur_systeme2' => '<b>Hard disk je mozda pun ili je baza podataka ostecena. <br />
	<font color=\'red\'>Pokusajte <a href=\'ecrire/admin_repair.php3\'>popravku baze podataka</a>, ili kontaktirajte vaseg hosta.</font><br /></b>', # MODIF
'info_fini' => 'Zavrseno je!',
'info_format_image' => 'Format fotografija koji se moze koristiti za kreiranje vinjeta: @gd_formats@.',
'info_format_non_defini' => 'neodredjen format',
'info_grand_ecran' => 'Veliki prikaz',
'info_image_aide' => 'POMOC',
'info_image_process_titre' => 'Metoda pravljenja vinjeta',
'info_impossible_lire_page' => '<b>Greska!</b> Nemoguce procitati stranicu <tt><html>@test_proxy@</html></tt> iako proxy <tt>', # MODIF
'info_inclusion_directe' => 'Direktno ukljucivanje:',
'info_inclusion_vignette' => 'Ukljuci vinjetu:',
'info_installation_systeme_publication' => 'Instalacija sistema objavljivanja...',
'info_installer_documents' => 'Mozete automatski instalirati sve dokumente iz foldera <i>upload</i>.',
'info_installer_ftp' => 'Kao administrator mozete putem FTP-a instalirati dokumente iz foldera @upload@ da bi ste ih kasnije izabrali direktno sa ove lokacije.',
'info_installer_images' => 'Mozete instalirati fotografije formata JPEG, GIF i PNG.',
'info_installer_images_dossier' => 'Instalirajte fotografije u folder @upload@ da bi ste ih mogli izabrati sa ov lokacije.',
'info_installer_tous_documents' => 'Instaliraj sve dokumente',
'info_interface_complete' => 'Cjelokupni interfejs',
'info_interface_simple' => 'Pojednostavljeni interfejs',
'info_joindre_document_article' => 'Ovom clanku mozete pridruziti dokumente tipa',
'info_joindre_document_rubrique' => 'Ovoj rubrici mozete dodati dokumente tipa',
'info_joindre_documents_article' => 'Vasem clanku mozete dodati dokumente tipa:',
'info_l_article' => '&#1063;&#1083;&#1072;&#1085;&#1072;&#1082;',
'info_la_breve' => 'obavjestenje',
'info_la_rubrique' => 'rubrika',
'info_langue_principale' => 'Glavni jezik stranice',
'info_largeur_vignette' => '@largeur_vignette@ &#215; @hauteur_vignette@ piksela',
'info_les_auteurs_1' => 'od @les_auteurs@',
'info_logo_format_interdit' => 'Dozvoljeni su samo logotipi formata @formats@.',
'info_logo_max_poids' => 'Logotip mora biti manji od @maxi@ (ovaj dokument je @actuel@).',
'info_logo_max_taille' => 'Logotip mora biti manji od @maxi@ (ovaj dokument je @actuel@).',
'info_mail_fournisseur' => 'vi@isp.com',
'info_message_2' => 'PORUKA',
'info_message_supprime' => 'PORUKA JE IZBRISANA',
'info_messages_nb' => '@nb@ messages', # NEW
'info_messages_un' => '1 message', # NEW
'info_mise_en_ligne' => 'Datum objavljivanja:',
'info_modification_parametres_securite' => 'Izmjena parametara sigurnosti',
'info_mois_courant' => 'Tokom mjeseca:',
'info_mot_cle_ajoute' => 'Sljedeca kljucna rijec je dodana u',
'info_multi_herit' => 'Standardni jezik',
'info_multi_langues_soulignees' => '<u>Podvuceni jezici</u> raspolazu prevodom svih tekstova interfejsa. Ako izaberete jedan od tih jezika, brojni elementi javne stranice (datumi, formulari) ce biti automatski prevedeni. Za nepodvucene jezike, ti ce elementi biti prikazani u glavnom jeziku stranice.', # MODIF
'info_multilinguisme' => 'Multilingvizam',
'info_nom_non_utilisateurs_connectes' => 'Vase ime se ne pojavljuje na listi prisutnih korisnika.',
'info_nom_utilisateurs_connectes' => 'Vase ime se pojavljuje na listi prisutnih korisnika.',
'info_nombre_en_ligne' => 'Trenutno prisutni:',
'info_non_resultat' => 'Nema rezultata za "@cherche_mot@"',
'info_non_utilisation_messagerie' => 'Ne koristite privatni servis poruka ove stranice.',
'info_nouveau_message' => 'NEMATE NOVIH PORUKA',
'info_nouveaux_messages' => 'IMATE @total_messages@ NOVIH PORUKA',
'info_numero_abbreviation' => 'N°',
'info_obligatoire' => 'Cette information est obligatoire', # NEW
'info_panne_site_syndique' => 'Sindikovana stranica nije u funkciji',
'info_pense_bete' => 'BILJESKA',
'info_petit_ecran' => 'Mali prikaz',
'info_petition_close' => 'P&eacute;tition close', # NEW
'info_pixels' => 'piksela',
'info_plusieurs_mots_trouves' => 'Pronadjeno je vise kljucnih rijeci za "@cherche_mot@":',
'info_popularite_5' => 'popularno:',
'info_portfolio' => 'Portfolio',
'info_portfolio_automatique' => 'Automatski portfolio:',
'info_premier_resultat' => '[@debut_limit@ prvih rezultata od ukupno @total@]',
'info_premier_resultat_sur' => '[@debut_limit@ prvih rezultata od ukupno @total@]',
'info_probleme_grave' => 'problem sa',
'info_propose_1' => '[@nom_site_spip@] Poslano: @titre@',
'info_propose_2' => 'Clanak je poslan
---------------',
'info_propose_3' => 'Clanak "@titre@" je predlozen za objavljivanje.',
'info_propose_4' => 'Mozete ga konsultovati i dati vase misljenje',
'info_propose_5' => 'u forumu koji mu je pridruzen. Dostupan je na adresi:',
'info_publie_01' => 'Clanak "@titre@" je ovjerio/la @connect_nom@.',
'info_publie_1' => '[@nom_site_spip@] OBJAVLJEN: @titre@',
'info_publie_2' => 'Clanak objavljen
--------------',
'info_rechercher' => 'Pretraga',
'info_rechercher_02' => 'Pretraga:',
'info_remplacer_vignette' => 'Automatski zamijeni vinjetu sa pesonalizovanim logotipom:',
'info_retablir_lien' => 'obnovi ovaj link',
'info_retirer_mot' => 'Odstrani ovu kljucnu rijec',
'info_retirer_mots' => 'Odstrani sve kljucne rijeci',
'info_rubriques_nb' => '@nb@ rubriques', # NEW
'info_rubriques_un' => '1 rubrique', # NEW
'info_sans_titre_2' => 'bez naslova',
'info_selectionner_fichier' => 'Mozete izabrati dokument iz foldera <i>upload</i>',
'info_selectionner_fichier_2' => 'Izaberite dokument:',
'info_signature_supprimee' => 'Signature supprim&eacute;e', # NEW
'info_signature_supprimee_erreur' => 'Erreur&nbsp;: ce code de suppression ne correspond a aucune signature', # NEW
'info_site_attente' => 'Web stranica ceka na ovjeru',
'info_site_reference' => 'Preporucene stranice online',
'info_site_refuse' => 'Web stranica odbijena',
'info_sites_nb' => '@nb@ sites', # NEW
'info_sites_referencer' => 'Preporuci stranicu',
'info_sites_un' => '1 site', # NEW
'info_supprimer_vignette' => 'izbrisi vinjetu',
'info_symbole_bleu' => 'Simbol <b>bleu</b> ukazuje na <b>pense-b&ecirc;te</b>: to jeste poruku za vasu licnu upotrebu.', # MODIF
'info_symbole_jaune' => 'Simbol <b>jaune</b> ukazuje na <b>najavu za sve urednike: Svi urednici ga mogu vidjeti i izmijeniti.', # MODIF
'info_symbole_vert' => 'Simbol <b>vert</b> ukazuje na <b>poruke razmijene sa drugim korisnicima</b> stranicama.', # MODIF
'info_syndication' => 'sindikacija:',
'info_syndication_articles' => 'clanak/ci',
'info_telecharger' => 'Upload sa vaseg kompjutera:',
'info_telecharger_nouveau_logo' => 'Upload novi logotip:',
'info_telecharger_ordinateur' => 'Upload sa vaseg kompjutera:',
'info_tous_resultats_enregistres' => '[registrovani su svi rezultati]',
'info_tout_afficher' => 'Prikazi sve',
'info_travaux_texte' => 'Ova stranica jos nije podesena. Vratite se kasnije...',
'info_travaux_titre' => 'Stranica pod konstrukcijom',
'info_trop_resultat' => 'Previse rezultata za "@cherche_mot@"; predefinisite opcije pretrazivnja.',
'info_utilisation_messagerie_interne' => 'Koristite interni servis poruka ove stranice.',
'info_valider_lien' => 'ovjeri ovaj link',
'info_verifier_image' => ', provjerite da li je transfer fotografija uspio.',
'info_vignette_defaut' => 'Standardna vinjeta',
'info_vignette_personnalisee' => 'Personalizovana vinjeta',
'info_visite' => 'posjeta:',
'info_visites' => 'posjete:',
'info_vos_rendez_vous' => 'Vasi sastanci koji slijede',
'info_zoom' => 'zoom',
'infos_vos_pense_bete' => 'Vase biljeske', # MODIF
'item_breve_proposee' => 'Predlozena obavjestenja',

// L
'lien_afficher_icones_seuls' => 'Prikazi samo ikone',
'lien_afficher_texte_icones' => 'Prikazi ikone i tekst',
'lien_afficher_texte_seul' => 'Prikazi samo tekst',
'lien_liberer' => 'izdanje',
'lien_liberer_tous' => 'izdaj ove clanke',
'lien_nouvea_pense_bete' => 'NOVA BILJESKA',
'lien_nouveau_message' => 'NOVA PORUKA',
'lien_nouvelle_annonce' => 'NOVA NAJAVA',
'lien_petitions' => 'PETICIJA',
'lien_popularite' => 'popularno: @popularite@%',
'lien_racine_site' => 'KORIJEN STRANICE',
'lien_reessayer' => 'pokusaj ponovo',
'lien_repondre_message' => 'Odgovori na ovu poruku',
'lien_supprimer' => 'izbrisi',
'lien_tout_afficher' => 'Prikazi sve',
'lien_visite_site' => 'posjeti ovu stranicu',
'lien_visites' => '@visites@ &#1087;&#1086;&#1089;&#1077;&#1090;&#1077;',
'lien_voir_auteur' => 'Pgledaj ovog autora',
'ligne' => 'Ligne', # NEW
'login' => 'Connexion', # NEW
'login_acces_prive' => 'pristup privatnom prostoru',
'login_autre_identifiant' => 'konektuj se drugim identifikatorom',
'login_cookie_accepte' => 'Podesite vas navigator da prihvata cookie (bar za ovu stranicu).',
'login_cookie_oblige' => 'Da bi ste se sigurno prijavili na ovu stranicu, morate prihvatiti cookie.',
'login_deconnexion_ok' => 'Odjavljeni ste.',
'login_erreur_pass' => 'Greska sa lozinkom.',
'login_espace_prive' => 'privatni prostor',
'login_identifiant_inconnu' => 'Identifikator &laquo; @login@ &raquo; je nepoznat.',
'login_login' => 'Login:',
'login_login2' => 'Login (identifikator za prijavu na stranicu)&nbsp;:',
'login_login_pass_incorrect' => '(Login ili lozinka nije ispravna.)',
'login_motpasseoublie' => 'zaboravili ste lozinku?',
'login_non_securise' => 'Oprez, ovaj formular nije siguran.
			Ako ne zelite da vasa lozinka bude dostupna na mrezi, aktivirajte 			Javascript u vasem navigatoru i',
'login_nouvelle_tentative' => 'Novi pokusaj',
'login_par_ici' => 'Registrovani ste... ovim putem...',
'login_pass2' => 'Lozinka:',
'login_preferez_refuser' => '<b>Ako zelite odbiti cookie</b>, na raspolaganju vam je drugi nacin prijavljivanja (manje siguran):',
'login_recharger' => 'ponovo ucitaj ovu stranicu',
'login_rester_identifie' => 'Ostanite identifikovani nekoliko dana',
'login_retour_public' => 'Nazad na javnu stranicu',
'login_retour_site' => 'Nazad na javnu stranicu',
'login_retoursitepublic' => 'nazad na javnu stranicu',
'login_sans_cookiie' => 'Identifikacija bez cookie',
'login_securise' => 'Login s&eacute;curis&eacute;', # NEW
'login_sinscrire' => 'registruj se',
'login_test_navigateur' => 'test navigatora/ponovna konekcija',
'login_verifiez_navigateur' => '(Svakako se uvjerite da vas navigator nije zapamtio vasu lozinku...)',

// M
'masquer_colonne' => 'Masquer cette colonne', # NEW
'masquer_trad' => 'masquer les traductions', # NEW
'module_fichiers_langues' => 'Jezicni dokumenti',

// N
'navigateur_pas_redirige' => 'Ako vas navigator nije preusmjeren, kliknite ovdje da biste nastavili.',
'numero' => 'Num&eacute;ro', # NEW

// O
'occurence' => 'Occurrence', # NEW
'onglet_affacer_base' => 'Izbrisi bazu',
'onglet_auteur' => 'Autor',
'onglet_contenu_site' => 'Sadrzaj stranice',
'onglet_evolution_visite_mod' => 'Nivo posjeta',
'onglet_fonctions_avances' => 'Napredne funkcije',
'onglet_informations_personnelles' => 'Licne informacije',
'onglet_interactivite' => 'Interaktivnost',
'onglet_messagerie' => 'Servis poruka',
'onglet_messages_internes' => 'Interne poruke',
'onglet_messages_publics' => 'Javne poruke',
'onglet_messages_vide' => 'Poruke bez teksta',
'onglet_origine_visites' => 'Porijeklo posjete',
'onglet_repartition_debut' => 'od pocetka',
'onglet_repartition_lang' => 'Distribicija po jezicima',
'onglet_repartition_rubrique' => 'Distribucija po rubrikama',
'onglet_save_restaur_base' => 'Backup/obnova baze podataka',
'onglet_vider_cache' => 'Isprazni kes',

// P
'pass_choix_pass' => 'Izaberite vasu novu lozinku:',
'pass_erreur' => 'Greska',
'pass_erreur_acces_refuse' => '<b>Greska:</b> vise nemate pristup ovoj stranici.',
'pass_erreur_code_inconnu' => '<b>Greska:</b> ovaj kod ne odgovara nijednom posjetiocu koji ima pristup ovoj stranici.',
'pass_erreur_non_enregistre' => '<b>Greska:</b> adresa <tt>@email_oubli@</tt> nije registgrovana na ovoj stranici.',
'pass_erreur_non_valide' => '<b>Greska:</b> ovaj e-mail <tt>@email_oubli@</tt> nije vazeci!',
'pass_erreur_probleme_technique' => '<b>Greska:</b> e-mail nije poslan, radi tehnickog problema.',
'pass_espace_prive_bla' => 'Privatni prostor ove stranice je otvoren za posjetioce nakon registrovanja. Nakon registracije, mozete konsultovati clanke u toku uredjivanja,
predlagati clanke i ucestvovati u svim forumima.',
'pass_forum_bla' => 'Trazili ste ucesce u forumu koji je rezervisan za registrovane posjetioce.',
'pass_indiquez_cidessous' => 'Ispod naznacite e-mail adresu sa kojom ste trenutno registrovani. Primicete e-mail sa putem koji trebate slijediti da biste ponovo dobili pristup.',
'pass_mail_passcookie' => '(ovo je automatska poruka)
Da biste ponovo dobili pristup
@nom_site_spip@ (@adresse_site@)

Idite na sljedecu adresu:

    @adresse_site@/spip_pass.php3?p=@cookie@

Tamo mozete unijeti novu lozinku i ponovo se prijaviti na stranicu.

',
'pass_mot_oublie' => 'Zaboravili ste lozinku',
'pass_nouveau_enregistre' => 'Vasa nova lozinka je registrovana.',
'pass_nouveau_pass' => 'Nova lozinka',
'pass_ok' => 'OK',
'pass_oubli_mot' => 'Zaboravljena lozinka',
'pass_quitter_fenetre' => 'Napusti ovaj prozor',
'pass_rappel_login' => 'Podsjetnik: vas identifikator (login) je &laquo; @login@ &raquo;.',
'pass_recevoir_mail' => 'Primicete e-mai sa uputstvom za pronalazenje vaseg pristupa.',
'pass_retour_public' => 'Nazad na javnu stranicu',
'pass_rien_a_faire_ici' => 'Ovdje nema nista za raditi.',
'pass_vousinscrire' => 'Registrujte se na srtranicu se na stranicu',
'precedent' => 'Nazad',
'previsualisation' => 'Pegled',
'previsualiser' => 'Pokazi pregled',

// R
'retour' => 'Retour', # NEW

// S
'spip_conforme_dtd' => 'SPIP consid&egrave;re ce document comme conforme &agrave; son DOCTYPE :', # NEW
'squelette' => 'predlozak',
'squelette_inclus_ligne' => 'ukjucen predlozak, linija',
'squelette_ligne' => 'predlozak linija',
'stats_visites_et_popularite' => '@visites@ posjete; popularno: @popularite@',
'suivant' => 'Naprijed',

// T
'taille_ko' => '@taille@&nbsp;kb',
'taille_mo' => '@taille@&nbsp;Mb',
'taille_octets' => '@taille@&nbsp;bit',
'texte_actualite_site_1' => 'Kada se naviknete na interfejs, kliknite na &laquo;',
'texte_actualite_site_2' => 'cjelokupni interfejs',
'texte_actualite_site_3' => '&raquo; za otveranje vise mogucnosti.',
'texte_creation_automatique_vignette' => 'Aktivirano je automatsko kreiranje vinjeta na ovoj stranici. Ako putem ovog formulara instalirate fotografije formata @gd_formats@, one ce biti popracene vinjetom maksimalne velicine @taille_preview@piksela.',
'texte_documents_associes' => 'Sljedeci dokumenti su povezani sa clankom,ali nisu direktno ukljuceni. Na osnovu izgleda javne stranice, mogu biti prikazani kao pridruzeni dokumenti',
'texte_erreur_mise_niveau_base' => 'Greska u bazi podataka tokom nadogradnje.
Fotografija <b>@fichier@</b> nije predjena (clanak @id_article@).
Obratite paznu na ovu referencu, ponovo pokusajte nadogradnju i na kraju provjerite da li se fotografije uvijek pojavljuju u clancima.', # MODIF
'texte_erreur_visiteur' => 'Vous avez tent&eacute; d\'acc&eacute;der &agrave; l\'espace priv&eacute; avec un login qui ne le permet pas.', # NEW
'texte_inc_auth_1' => 'Identifikovani ste pod loginom <b>@auth_login@</b>, ali on vise ne postoji u bazi. Pokusajte se ponovo', # MODIF
'texte_inc_auth_2' => 'prijaviti',
'texte_inc_auth_3' => ', nakon sto ste iskljucili, a zatim ponovo ukljucili vas navigator.',
'texte_inc_config' => 'Dole unesene modifikacije znatno uticu na funkcionisanje vase stranice. Preporucuje se da ne intervenisete ako niste upoznati sa SPIP sistemom. <br /><br /><b>Generalno se preporucuje intervencija webmastera ove stranice.</b>', # MODIF
'texte_inc_meta_1' => 'Sistem je naisao na gresku pri pokusaju da pise dokument <code>ecrire/data/meta_cache.php3</code>. Kao administrator stranice,',
'texte_inc_meta_2' => 'mozete provjeriti dozvolu pisanja',
'texte_inc_meta_3' => 'u direktorij <code>ecrire/data/</code>.',
'texte_statut_en_cours_redaction' => 'U toku uredjivanja',
'texte_statut_poubelle' => 'u korpi za smece',
'texte_statut_propose_evaluation' => 'predlozeno za izglasavanje',
'texte_statut_publie' => 'objavljeno',
'texte_statut_refuse' => 'odbijeno',
'titre_ajouter_mot_cle' => 'DODATI KLJUCNU RIJEC:',
'titre_breve_proposee' => 'Predlozeno obavjestenje',
'titre_breve_publiee' => 'Obavjestenje objavljeno',
'titre_breve_refusee' => 'Obavjestenje odbijeno',
'titre_cadre_raccourcis' => 'PRECICE:',
'titre_changer_couleur_interface' => 'Promijeni boju interfejsa',
'titre_forum' => 'Forum',
'titre_image_admin_article' => 'Mozete administrirati ovaj clanak',
'titre_image_administrateur' => 'Administrator',
'titre_image_aide' => 'Pomoc sa ovim elementom',
'titre_image_auteur_supprime' => 'Autor izbrisan',
'titre_image_redacteur' => 'Urednik bez pristupa',
'titre_image_redacteur_02' => 'Urednik',
'titre_image_visiteur' => 'Posjetioc',
'titre_joindre_document' => 'PRIDRUZI DOKUMENT',
'titre_liens_entrants' => 'Unosenje linkova',
'titre_mots_cles' => 'KLJUCNE RIJECI',
'titre_probleme_technique' => 'Upozorenje: tehnicki problem (SQL server) sprijecava pristup ovom dijelu stranice. Hvala na razumijevanju.', # MODIF
'titre_publier_document' => 'OBJAVI DOKUMENT U OVOJ RUBRICI',
'titre_signatures_attente' => 'Signatures en attente de validation', # NEW
'titre_signatures_confirmees' => 'Signatures confirm&eacute;es', # NEW
'titre_statistiques' => 'Statistike stranice',
'titre_titre_document' => 'Naslov dokumenta:',
'todo' => '&agrave; venir', # NEW
'trad_reference' => '(preporuceni clanak)',

// Z
'zbug_balise_b_aval' => '&nbsp;: oznaka B kasni u petlji',
'zbug_balise_inexistante' => 'erreur @from@: la balise #@balise@ n\'existe pas', # MODIF
'zbug_balise_sans_argument' => 'Argument manquant dans la balise @balise@', # NEW
'zbug_boucle' => 'petlja',
'zbug_boucle_recursive_undef' => 'nedefinisana rakurzivna petlja', # MODIF
'zbug_calcul' => 'calcul', # NEW
'zbug_champ_hors_boucle' => 'Polje @champ@ izvan petlje',
'zbug_champ_hors_motif' => 'Polje @champ@ van oznacene petlje @motif@', # MODIF
'zbug_code' => 'kod',
'zbug_critere_inconnu' => 'nepoznat kriterij @critere@', # MODIF
'zbug_distant_interdit' => 'zabranjeni eksterni podaci', # MODIF
'zbug_doublon_table_sans_cle_primaire' => 'doublons sur une table sans clef primaire atomique', # MODIF
'zbug_doublon_table_sans_index' => 'doublons sur une table sans index', # MODIF
'zbug_erreur_boucle_double' => 'BOUCLE@id@: dupla definicija', # MODIF
'zbug_erreur_boucle_fermant' => 'BOUCLE@id@: zatvarajuca oznaka nedostaje', # MODIF
'zbug_erreur_boucle_syntaxe' => 'Pogresna sintaksa petlje', # MODIF
'zbug_erreur_compilation' => 'Erreur de compilation', # NEW
'zbug_erreur_execution_page' => 'greska pri izvodjenju stranice', # MODIF
'zbug_erreur_filtre' => 'Greska: nedefinisan filter <b>&laquo; @filtre@ &raquo;</b>', # MODIF
'zbug_erreur_meme_parent' => '{meme_parent} odnosi se samo na petlje (FORUMI) ili (RUBRIKE)', # MODIF
'zbug_erreur_squelette' => 'Greska sa predloskom',
'zbug_hors_compilation' => 'Hors Compilation', # NEW
'zbug_info_erreur_squelette' => 'Greska na stranici',
'zbug_inversion_ordre_inexistant' => 'inverzija nepostojecim rasporedom', # MODIF
'zbug_pagination_sans_critere' => '#PAGINATION sans crit&egrave;re {pagination} ou employ&eacute; dans une boucle recursive', # MODIF
'zbug_parametres_inclus_incorrects' => 'Pogresni parametri ukljucivanja', # MODIF
'zbug_profile' => 'Temps de calcul&nbsp;: @time@', # NEW
'zbug_resultat' => 'rezultat',
'zbug_serveur_indefini' => 'nedefinisan SQL server', # MODIF
'zbug_statistiques' => 'Statistiques des requ&ecirc;tes SQL class&eacute;es par dur&eacute;e', # NEW
'zbug_table_inconnue' => 'Nedefinisana SQL  tabela &laquo; @table@ &raquo;',
'zxml_connus_attributs' => 'attributs connus', # NEW
'zxml_de' => 'de', # NEW
'zxml_inconnu_attribut' => 'attribut inconnu', # NEW
'zxml_inconnu_balise' => 'balise inconnue', # NEW
'zxml_inconnu_entite' => 'entit&eacute; inconnue', # NEW
'zxml_inconnu_id' => 'ID inconnu', # NEW
'zxml_mais_de' => 'mais de', # NEW
'zxml_non_conforme' => 'n\'est pas conforme au motif', # NEW
'zxml_non_fils' => 'n\'est pas un fils de', # NEW
'zxml_nonvide_balise' => 'balise non vide', # NEW
'zxml_obligatoire_attribut' => 'attribut obligatoire mais absent dans', # NEW
'zxml_succession_fils_incorrecte' => 'succession des fils incorrecte', # NEW
'zxml_survoler' => 'survoler pour voir les corrects', # NEW
'zxml_valeur_attribut' => 'valeur de l\'attribut', # NEW
'zxml_vide_balise' => 'balise vide', # NEW
'zxml_vu' => 'vu auparavant', # NE
);

?>
